# Generated by roxygen2: do not edit by hand

export(.digit256)
export(.permitted_street_type_ord)
export(HashStreetName)
export(compress_latlon)
export(compress_latlon_general)
export(decompress_latlon)
export(decompress_latlon_general)
export(download_latlon_data)
export(extract_flatNumberFirstLast)
export(extract_postcode)
export(match_StreetType)
export(match_word)
export(mutate_latlon)
export(nany_lowercase)
export(postcode2ste)
export(read_ste_fst)
export(standard_address2)
export(standard_address3)
export(standardize_address)
export(toupper_basic)
export(unHashStreetName)
export(uniqueN_Postcodes)
export(unique_Postcodes)
import(data.table, except = "%notin%")
importFrom(fastmatch,"%fin%")
importFrom(fastmatch,fmatch)
importFrom(hutils,"%notin%")
importFrom(hutils,coalesce)
importFrom(hutils,provide.dir)
importFrom(hutilscpp,coalesce0)
importFrom(hutilscpp,fmatchp)
importFrom(hutilscpp,isntConstant)
importFrom(hutilscpp,minmax)
importFrom(magrittr,"%>%")
importFrom(tools,R_user_dir)
importFrom(utils,download.file)
importFrom(utils,hasName)
importFrom(utils,head)
importFrom(utils,packageName)
useDynLib(healthyAddress, .registration = TRUE)
